@@ -196,7 +196,7 @@ class PageAdmin(DisplayableAdmin):
             except NoReverseMatch:
                 continue
             else:
-                setattr(model, "name", model._meta.verbose_name)
+                setattr(model, "meta_verbose_name", model._meta.verbose_name)
                 setattr(model, "add_url", admin_url(model, "add"))
                 models.append(model)
         order = [name.lower() for name in settings.ADD_PAGE_ORDER]
@@ -204,9 +204,9 @@ class PageAdmin(DisplayableAdmin):
         def sort_key(page):
             name = "%s.%s" % (page._meta.app_label, page._meta.object_name)
             try:
-                order.index(name.lower())
+                return order.index(name.lower())
             except ValueError:
-                return page.name
+                return page.meta_verbose_name
         return sorted(models, key=sort_key)
 
 # Drop the meta data fields, and move slug towards the stop.
